==> plasma-workspace_5.20.5.orig.tar.xz: plasma-workspace-5.20.5/runners/appstream/appstreamrunner.h <==
/***************************************************************************
 *   Copyright © 2016 Aleix Pol Gonzalez <aleixpol@kde.org>                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef APPSTREAMRUNNER_H
#define APPSTREAMRUNNER_H

#include <KRunner/AbstractRunner>
#include <AppStreamQt/pool.h>
#include <QMutex>

class InstallerRunner : public Plasma::AbstractRunner
{
Q_OBJECT

public:
    InstallerRunner(QObject *parent, const QVariantList &args);
    ~InstallerRunner() override;

    void match(Plasma::RunnerContext &context) override;
    void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &action) override;

private:
    QList<AppStream::Component> findComponentsByString(const QString &query);

    AppStream::Pool m_db;
    QMutex m_appstreamMutex;
};

#endif

==> plasma-workspace-5.22.2.tar.xz: plasma-workspace-5.22.2/runners/appstream/appstreamrunner.h <==
/***************************************************************************
 *   Copyright © 2016 Aleix Pol Gonzalez <aleixpol@kde.org>                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef APPSTREAMRUNNER_H
#define APPSTREAMRUNNER_H

#include <AppStreamQt/pool.h>
#include <KRunner/AbstractRunner>
#include <QMutex>

class InstallerRunner : public Plasma::AbstractRunner
{
    Q_OBJECT

public:
    InstallerRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
    ~InstallerRunner() override;

    void match(Plasma::RunnerContext &context) override;
    void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &action) override;

private:
    QList<AppStream::Component> findComponentsByString(const QString &query);

    AppStream::Pool m_db;
    QMutex m_appstreamMutex;
};

#endif
